/**
 * Validates that the Null, Object or Array value matches the schema.
 * @param schema	Null, Object or Array schema to match.
 * @param value		Value to be validated.
 * @param property	Name of the property being validated.
 */
export declare function ValidateObject<T>(schema: T, value: any, property: string): T;
export declare function ValidateFunction<T extends () => {}>(schema: T, value: any, property: string): T;
/**
 * Validates that the value is string literal.
 * @param schema    String literal to match.
 * @param value     Value to be validated.
 * @param property  Name of the property being validated.
 */
export declare function LiteralString(schema: string, value: any, property: string): string;
/**
 * Validates that the value is number literal.
 * @param schema    Number literal to match.
 * @param value     Value to be validated.
 * @param property  Name of the property being validated.
 */
export declare function LiteralNumber(schema: number, value: any, property: string): number;
/**
 * Validates that the value is boolean literal.
 * @param schema    Boolean literal to match.
 * @param value     Value to be validated.
 * @param property  Name of the property being validated.
 */
export declare function LiteralBoolean(schema: boolean, value: any, property: string): boolean;
/**
 * Validates that the value is Symbol.
 * @param schema    Symbol schema to match.
 * @param value     Value to be validated.
 * @param property  Name of the property being validated.
 */
export declare function LiteralSymbol(schema: symbol, value: any, property: string): symbol;
/**
 * Validates that the value is undefined.
 * @param schema    Redundant.
 * @param value     Value to be validated.
 * @param property  Name of the property being validated.
 */
export declare function Undefined(schema: undefined, value: any, property: string): undefined;
/**
 * Validates that the value is null.
 * @param schema    Redundant.
 * @param value     Value to be validated.
 * @param property  Name of the property being validated.
 */
export declare function Null(schema: null, value: any, property: string): null;
/**
 * Throws an unknown type validation error.
 * @param schema    Redundant.
 * @param value     Value to be validated.
 * @param property  Name of the property being validated.
 */
export declare function Unknown<T>(schema: T, value: any, property: string): T;
export declare function banner(log: any): void;
export declare function validate<T>(schema: T, value: any, log?: any, name?: string): T;
